#' Check a data object for compatibility with differential expression functions
#' 
#' Check if an object (a list) contains the necessary entries for applying the differential expression functions provided within the \code{compcodeR} package (a count matrix, an annotation giving the condition of each sample and a data set name).
#' 
#' @param data.obj A list containing data and condition information, for example an object generated by the \code{\link{generateSyntheticData}} function.
#' @author Charlotte Soneson
#' @export
#' @examples
#' mydata.obj <- generateSyntheticData(dataset = "mydata", n.vars = 12500, 
#'                                     samples.per.cond = 5, n.diffexp = 1250, 
#'                                     output.file = "mydata.rds")
#' checkDataObject(mydata.obj)
checkDataObject = function(data.obj) {
  if (is.null(data.obj$count.matrix)) {
    stop("Data object does not contain a count matrix")
  } else if (is.null(data.obj$sample.annotation$condition)) {
    stop("Data object does not contain a condition vector")
  } else if (is.null(data.obj$info.parameters$dataset)) {
    stop("Data object does not contain a data set name")
  } else {
    "Data object looks ok."
  }
}
