\name{generateCodeHTMLs}
\alias{generateCodeHTMLs}
\title{Generate HTML file(s) containing code used to run differential expression analysis.}
\usage{
  generateCodeHTMLs(input.files, output.directory)
}
\arguments{
  \item{input.files}{A vector with paths to one or several
  .rds objects containing the results from differential
  expression analysis. One code HTML file is generated for
  each element in the vector.}

  \item{output.directory}{The path to the directory where
  the code HTML files will be saved.}
}
\description{
  A function to extract the code used to generate
  differential expression results from saved result objects
  (typically obtained by \code{\link{runDiffExp}}), and to
  write the code to HTML files. This requires that the code
  was saved as a string in the \code{code} slot of the
  result object, which is done automatically by
  \code{\link{runDiffExp}}. If the differential expression
  analysis was performed with functions outside
  \code{compcodeR}, the code has to be added manually to
  the result object.
}
\examples{
mydata.obj <- generateSyntheticData(dataset = "mydata", n.vars = 12500,
                                    samples.per.cond = 5, n.diffexp = 1250,
                                    output.file = "mydata.rds")
runDiffExp(data.file = "mydata.rds", result.extent = "voom.limma",
           Rmdfunction = "voom.limma.createRmd", output.directory = ".",
           norm.method = "TMM")
generateCodeHTMLs("mydata_voom.limma.rds", ".")
}
\author{
  Charlotte Soneson
}

