\name{runDiffExp}
\alias{runDiffExp}
\title{The main function to run differential expression analysis}
\usage{
  runDiffExp(data.file, result.extent, Rmdfunction,
    output.directory = ".", norm.path = TRUE, ...)
}
\arguments{
  \item{data.file}{The path to a \code{.rds} object
  containing the data on which the differential expression
  analysis will be performed, for example a data object
  returned from \code{\link{generateSyntheticData}}.}

  \item{result.extent}{The extension that will be added to
  the data file name in order to construct the result file
  name. This can be for example the differential expression
  method together with a version number.}

  \item{Rmdfunction}{A function that creates an Rmd file
  containing the code that should be run to perform the
  differential expression analysis.}

  \item{output.directory}{The directory in which the result
  object will be saved.}

  \item{norm.path}{Logical, whether to include the full
  (absolute) path to the output object in the saved code.}

  \item{...}{Additional arguments that will be passed to
  the \code{Rmdfunction}, such as parameter choices for the
  differential expression method.}
}
\description{
  The main function for running differential expression
  analysis (comparing two conditions), using one of the
  methods provided in compcodeR or a user-defined method.
}
\examples{
mydata.obj <- generateSyntheticData(dataset = "mydata", n.vars = 12500,
                                    samples.per.cond = 5, n.diffexp = 1250,
                                    output.file = "mydata.rds")
checkDataObject(mydata.obj)
listcreateRmd()
runDiffExp(data.file = "mydata.rds", result.extent = "voom.limma",
           Rmdfunction = "voom.limma.createRmd",
           output.directory = ".", norm.method = "TMM")
}
\author{
  Charlotte Soneson
}

